zego_uikit_prebuilt_call
library
Classes
-
ZegoCallAndroidNotificationChannelConfig
-
-
ZegoCallAndroidNotificationConfig
-
android notification config
-
ZegoCallAudioEffectConfig
-
Configuration options for voice changer, beauty effects and reverberation effects.
-
ZegoCallAudioVideoEvents
-
events about audio-video
-
ZegoCallAudioVideoViewConfig
-
Configuration options for audio/video views.
-
ZegoCallBeautyEvents
-
-
Configuration options for the bottom menu bar (toolbar).
You can use the ZegoUIKitPrebuiltCallConfig.bottomMenuBar property to set the properties inside this class.
-
ZegoCallButtonUIConfig
-
Button UI configuration class for button visibility, size, icons, and styling.
-
ZegoCallControllerAudioVideoAudioOutputImpl
-
-
ZegoCallControllerAudioVideoCameraImpl
-
摄像头控制器 - 控制摄像头开关、前后摄像头切换、镜像模式等
-
ZegoCallControllerAudioVideoImpl
-
Here are the APIs related to audio video.
-
ZegoCallControllerAudioVideoMicrophoneImpl
-
麦克风控制器 - 控制麦克风开关和状态查询
-
ZegoCallControllerInvitationImpl
-
Here are the APIs related to invitation.
-
ZegoCallControllerLogImpl
-
Log controller for exporting and collecting call-related logs.
-
ZegoCallControllerMinimizePrivateActiveUser
-
-
ZegoCallControllerMinimizingImpl
-
Minimization controller implementation providing call interface minimization and restoration functionality.
-
ZegoCallControllerPermissionImpl
-
Here are the APIs related to audio video.
-
ZegoCallControllerPIPImpl
-
Picture-in-Picture (PIP) controller for enabling and disabling PIP functionality.
-
ZegoCallControllerRoomImpl
-
Room controller managing room-related operations such as token renewal.
-
ZegoCallControllerScreenSharingImpl
-
Screen sharing controller managing screen sharing display and fullscreen mode.
-
ZegoCallControllerUserImpl
-
Here are the APIs related to user
-
ZegoCallDeviceConfig
-
-
ZegoCallDurationConfig
-
Call timing configuration.
You can use the ZegoUIKitPrebuiltCallConfig.duration property to set the properties inside this class.
-
ZegoCallEndEvent
-
-
ZegoCallHangUpConfirmationEvent
-
-
ZegoCallHangUpConfirmDialogConfig
-
Confirmation dialog when hang up the call.
-
ZegoCallHangUpConfirmDialogInfo
-
-
ZegoCallingBuilderInfo
-
-
ZegoCallInRoomChatViewConfig
-
Control options for the bottom-left message list.
This class is used for the
chatView property of ZegoUIKitPrebuiltCallConfig.
-
ZegoCallInvitationConfig
-
Call invitation configuration class for permissions, offline invitations, in-call invitations, etc.
-
ZegoCallInvitationData
-
-
ZegoCallInvitationInCallingConfig
-
-
ZegoCallInvitationInnerText
-
Control the text on the UI.
Modify the values of the corresponding properties to modify the text on the UI.
You can also change it to other languages.
This class is used for the ZegoUIKitPrebuiltCall.innerText property.
Note that the placeholder %0 in the text will be replaced with the corresponding username.
-
ZegoCallInvitationInviteeMinimizedUIConfig
-
-
ZegoCallInvitationInviteeUIConfig
-
-
ZegoCallInvitationInviterMinimizedUIConfig
-
-
ZegoCallInvitationInviterUIConfig
-
-
ZegoCallInvitationMissedCallConfig
-
-
ZegoCallInvitationNotificationConfig
-
-
Invitation popup UI configuration class for displaying invitation popups and custom builders when receiving invitations.
-
ZegoCallInvitationOfflineConfig
-
-
ZegoCallInvitationPermissions
-
-
ZegoCallInvitationPIPConfig
-
pip config
-
ZegoCallInvitationPIPIOSConfig
-
iOS pip
only available on 15.0
-
ZegoCallInvitationServiceAPIImpl
-
Here are the APIs related to invitation.
-
ZegoCallInvitationServiceIOSCallKitPrivatePrivateImpl
-
Here are the APIs related to invitation.
-
ZegoCallInvitationServicePrivateImpl
-
Here are the APIs related to invitation.
-
ZegoCallInvitationUIConfig
-
Call invitation UI configuration class for invitation interface styling and custom builders.
-
ZegoCallIOSNotificationConfig
-
iOS notification config
-
ZegoCallMemberListConfig
-
Configuration for the member list.
You can use the ZegoUIKitPrebuiltCallConfig.memberList property to set the properties inside this class.
-
ZegoCallMinimizeData
-
Minimized data - using union type pattern
-
ZegoCallPIPAndroidConfig
-
android pip
only available on SDK higher than 26(>=26)
-
ZegoCallPIPConfig
-
pip config
-
ZegoCallPIPIOSConfig
-
iOS pip
only available on 15.0
-
ZegoCallRequiredUserConfig
-
Necessary participants to participate in the call.
-
ZegoCallRingtoneConfig
-
Ringtone configuration class for online calls (offline calls require configuration in the console).
Note that it only works for online calls. If it is offline, please configure it in the zego console
-
ZegoCallRoomEvents
-
events about room
-
ZegoCallScreenSharingAutoStopConfig
-
when ending screen sharing from a non-app,
the automatic check end mechanism will be triggered.
-
ZegoCallScreenSharingConfig
-
screen sharing
-
ZegoCallSystemConfirmDialogConfig
-
Confirmation dialog like system.
-
ZegoCallSystemConfirmDialogInfo
-
-
Configuration options for the top menu bar (toolbar).
You can use the ZegoUIKitPrebuiltCallConfig.topMenuBar property to set the properties inside this class.
-
ZegoCallUser
-
User In Call
-
ZegoCallUserConfig
-
-
ZegoCallUserEvents
-
events about user
-
ZegoInCallMinimizeData
-
In-call minimized data
-
ZegoInvitingMinimizeData
-
Inviting minimized data
-
ZegoSendCallingInvitationButton
-
This button is used to invite again when already in calling
-
ZegoSendCallingInvitationList
-
-
ZegoSendCallInvitationButton
-
This button is used to send a call invitation to one or more specified users.
-
ZegoUIKitPrebuiltCall
APIs
Events
Configs
Components
Migration_v4.x
-
Call Widget.
You can embed this widget into any page of your project to integrate the functionality of a call.
You can refer to our documentation,
or our sample code.
-
ZegoUIKitPrebuiltCallConfig
-
Configuration for initializing the Call
This class is used as the
config parameter for the constructor of ZegoUIKitPrebuiltCall.
-
ZegoUIKitPrebuiltCallController
-
Used to control the call functionality.
-
ZegoUIKitPrebuiltCallEvents
-
-
ZegoUIKitPrebuiltCallInnerText
-
Control the text on the UI.
Modify the values of the corresponding properties to modify the text on the UI.
You can also change it to other languages.
This class is used for the ZegoUIKitPrebuiltCallConfig.innerText property.
-
ZegoUIKitPrebuiltCallInvitationEvents
-
Invitation-related event notifications and callbacks.
You can listen to events that you are interested in here.
-
ZegoUIKitPrebuiltCallInvitationService
-
To receive the call invites from others and let the calling notification show on the top bar when receiving it, you will need to initialize the call invitation service (ZegoUIKitPrebuiltCallInvitationService) first.
-
ZegoUIKitPrebuiltCallMiniOverlayMachine
-
-
ZegoUIKitPrebuiltCallMiniOverlayPage
-
The page can be minimized within the app
-
ZegoUIKitPrebuiltCallMiniPopScope
-
When minimizing, it is not allowed to directly return to the previous page, otherwise the page will be destroyed
Enums
-
ZegoCallEndReason
-
The default behavior is to return to the previous page.
-
ZegoCallInvitationPermission
-
-
ZegoCallInvitationType
-
Call Type
-
Predefined buttons that can be added to the top or bottom toolbar.
By configuring these options, users can customize their own top menu bar or bottom toolbar.
This enum type is used in ZegoUIKitPrebuiltCallConfig.bottomMenuBarConfig and ZegoUIKitPrebuiltCallConfig.topMenuBarConfig.
-
This enum consists of two style options: light and dark. T
he light style represents a light theme with a transparent background,
while the dark style represents a dark theme with a black background.
You can use these options to set the desired theme style for the menu bar.
-
ZegoCallMiniOverlayPageState
-
Overlay window state
-
ZegoMinimizeType
-
Minimization type
Functions
-
showCallingInvitationListSheet(BuildContext context, {required List<ZegoCallUser> waitingSelectUsers, required void onPressed(List<ZegoCallUser> selectedUsers), bool defaultChecked = true, List<ZegoCallUser> selectedUsers = const [], List<ZegoCallUser> userSort(List<ZegoCallUser>)?, bool rootNavigator = false, ButtonIcon? buttonIcon, Size? buttonIconSize, Size? buttonSize, ZegoAvatarBuilder? avatarBuilder, Color? userNameColor, Color? backgroundColor, Widget? inviteButtonIcon})
→ void
-
Display a call invitation list pop-up.
Typedefs
-
CallEndCallback
= ZegoCallEndCallback
-
-
CallHangUpConfirmationCallback
= ZegoCallHangUpConfirmationCallback
-
-
PrebuiltCallMiniOverlayPageState
= ZegoCallMiniOverlayPageState
-
-
PrebuiltConfigQuery
= ZegoCallPrebuiltConfigQuery
-
-
ZegoAndroidNotificationConfig
= ZegoCallAndroidNotificationConfig
-
-
-
ZegoCallAudioVideoContainerBuilder
= Widget? Function(BuildContext context, List<ZegoUIKitUser> allUsers, List<ZegoUIKitUser> audioVideoUsers, ZegoAudioVideoView audioVideoViewCreator(ZegoUIKitUser))
-
-
ZegoCallEndCallback
= void Function(ZegoCallEndEvent event, VoidCallback defaultAction)
-
-
ZegoCallHangUpConfirmationCallback
= Future<bool> Function(ZegoCallHangUpConfirmationEvent event, Future<bool> defaultAction())
-
-
ZegoCallingBackgroundBuilder
= Widget? Function(BuildContext context, Size size, ZegoCallingBuilderInfo info)
-
-
ZegoCallingBackgroundBuilderInfo
= ZegoCallAudioEffectConfig
-
-
ZegoCallingForegroundBuilder
= Widget? Function(BuildContext context, Size size, ZegoCallingBuilderInfo info)
-
-
ZegoCallingPageBuilder
= Widget? Function(BuildContext context, ZegoCallingBuilderInfo info)
-
-
ZegoCallInvitationNotifyDialogBuilder
= Widget Function(ZegoCallInvitationData invitationData)
-
-
ZegoCallPermissionConfirmDialogConfig
= ZegoCallSystemConfirmDialogConfig
-
-
ZegoCallPermissionConfirmDialogInfo
= ZegoCallSystemConfirmDialogInfo
-
-
ZegoCallType
= ZegoCallInvitationType
-
-
ZegoHangUpConfirmDialogInfo
= ZegoCallHangUpConfirmDialogInfo
-
-
ZegoInRoomChatViewConfig
= ZegoCallInRoomChatViewConfig
-
-
ZegoInvitationType
= ZegoCallInvitationType
-
-
ZegoIOSNotificationConfig
= ZegoCallIOSNotificationConfig
-
-
ZegoLiveStreamingAudioEffectConfig
= ZegoCallAudioEffectConfig
-
-
ZegoMemberListConfig
= ZegoCallMemberListConfig
-
-
-
-
ZegoMiniOverlayPage
= ZegoUIKitPrebuiltCallMiniOverlayPage
-
-
ZegoPrebuiltAudioVideoViewConfig
= ZegoCallAudioVideoViewConfig
-
-
ZegoRingtoneConfig
= ZegoCallRingtoneConfig
-
-
-
ZegoUIKitCallEndEvent
= ZegoCallEndEvent
-
-
ZegoUIKitCallEndReason
= ZegoCallEndReason
-
-
ZegoUIKitCallHangUpConfirmationEvent
= ZegoCallHangUpConfirmationEvent
-
-
ZegoUIKitPrebuiltCallAudioVideoEvents
= ZegoCallAudioVideoEvents
-
-
ZegoUIKitPrebuiltCallRoomEvents
= ZegoCallRoomEvents
-
-
ZegoUIKitPrebuiltCallUserEvents
= ZegoCallUserEvents
-