ZegoCallInvitationInnerText class

Control the text on the UI. Modify the values of the corresponding properties to modify the text on the UI. You can also change it to other languages. This class is used for the ZegoUIKitPrebuiltCall.innerText property. Note that the placeholder %0 in the text will be replaced with the corresponding username.

Available extensions

Constructors

ZegoCallInvitationInnerText({String? incomingVideoCallDialogTitle, String? incomingVideoCallDialogMessage, String? incomingVoiceCallDialogTitle, String? incomingVoiceCallDialogMessage, String? incomingVideoCallPageTitle, String? incomingVideoCallPageMessage, String? incomingVoiceCallPageTitle, String? incomingVoiceCallPageMessage, String? incomingCallPageDeclineButton, String? incomingCallPageAcceptButton, String? outgoingCallPageACancelButton, String? outgoingVideoCallPageTitle, String? outgoingVideoCallPageMessage, String? outgoingVoiceCallPageTitle, String? outgoingVoiceCallPageMessage, String? incomingGroupVideoCallDialogTitle, String? incomingGroupVideoCallDialogMessage, String? incomingGroupVoiceCallDialogTitle, String? incomingGroupVoiceCallDialogMessage, String? incomingGroupVideoCallPageTitle, String? incomingGroupVideoCallPageMessage, String? incomingGroupVoiceCallPageTitle, String? incomingGroupVoiceCallPageMessage, String? outgoingGroupVideoCallPageTitle, String? outgoingGroupVideoCallPageMessage, String? outgoingGroupVoiceCallPageTitle, String? outgoingGroupVoiceCallPageMessage, String? missedCallNotificationTitle, String? missedGroupVideoCallNotificationContent, String? missedGroupAudioCallNotificationContent, String? missedVideoCallNotificationContent, String? missedAudioCallNotificationContent, String? systemAlertWindowConfirmDialogSubTitle, String? permissionManuallyConfirmDialogTitle, String? permissionManuallyConfirmDialogSubTitle, String? permissionConfirmDialogTitle, String? permissionConfirmDialogAllowButton, String? permissionConfirmDialogDenyButton, String? permissionConfirmDialogCancelButton, String? permissionConfirmDialogOKButton, String? callingToolbarMicrophoneButtonText, String? callingToolbarMicrophoneOnButtonText, String? callingToolbarMicrophoneOffButtonText, String? callingToolbarSpeakerButtonText, String? callingToolbarSpeakerOnButtonText, String? callingToolbarSpeakerOffButtonText, String? callingToolbarCameraButtonText, String? callingToolbarCameraOnButtonText, String? callingToolbarCameraOffButtonText, String? minimizedCallingPageWaitingText})

Properties

callingToolbarCameraButtonText String
The text below the camera button in the calling toolbar, The default value is "Camera".
getter/setter pair
callingToolbarCameraOffButtonText String
The text below the camera button when it's OFF in the calling toolbar, The default value is "Camera OFF".
getter/setter pair
callingToolbarCameraOnButtonText String
The text below the camera button when it's ON in the calling toolbar, The default value is "Camera ON".
getter/setter pair
callingToolbarMicrophoneButtonText String
The text below the microphone button in the calling toolbar, The default value is "Microphone".
getter/setter pair
callingToolbarMicrophoneOffButtonText String
The text below the microphone button when it's OFF in the calling toolbar, The default value is "Microphone OFF".
getter/setter pair
callingToolbarMicrophoneOnButtonText String
The text below the microphone button when it's ON in the calling toolbar, The default value is "Microphone ON".
getter/setter pair
callingToolbarSpeakerButtonText String
The text below the speaker button in the calling toolbar, The default value is "Speaker".
getter/setter pair
callingToolbarSpeakerOffButtonText String
The text below the speaker button when it's OFF in the calling toolbar, The default value is "Speaker OFF".
getter/setter pair
callingToolbarSpeakerOnButtonText String
The text below the speaker button when it's ON in the calling toolbar, The default value is "Speaker ON".
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
incomingCallPageAcceptButton String
The button on the call bottom bar to accept current incoming call. The default value is "Accept".
getter/setter pair
incomingCallPageDeclineButton String
The button on the call bottom bar to decline current incoming call. The default value is "Decline".
getter/setter pair
incomingGroupVideoCallDialogMessage String
The message of the incoming group video call dialog, The default value is "Incoming group video call...".
getter/setter pair
incomingGroupVideoCallDialogTitle String
The title of the incoming group video call dialog, The default value is inviter's name.
getter/setter pair
incomingGroupVideoCallPageMessage String
The message of the incoming group video call page, The default value is "Incoming group video call...".
getter/setter pair
incomingGroupVideoCallPageTitle String
The title of the incoming group video call page, The default value is inviter's name.
getter/setter pair
incomingGroupVoiceCallDialogMessage String
The message of the incoming group voice call dialog, The default value is "Incoming group voice call...".
getter/setter pair
incomingGroupVoiceCallDialogTitle String
The title of the incoming group voice call dialog, The default value is inviter's name.
getter/setter pair
incomingGroupVoiceCallPageMessage String
The message of the incoming group voice call page, The default value is "Incoming group voice call...".
getter/setter pair
incomingGroupVoiceCallPageTitle String
The title of the incoming group voice call page, The default value is inviter's name.
getter/setter pair
incomingVideoCallDialogMessage String
The message of the incoming video call dialog, The default value is "Incoming video call...".
getter/setter pair
incomingVideoCallDialogTitle String
The title of the incoming video call dialog, The default value is inviter's name.
getter/setter pair
incomingVideoCallPageMessage String
The message of the incoming video call page, The default value is "Incoming video call...".
getter/setter pair
incomingVideoCallPageTitle String
The title of the incoming video call page, The default value is inviter's name.
getter/setter pair
incomingVoiceCallDialogMessage String
The message of the incoming voice call dialog, The default value is "Incoming voice call...".
getter/setter pair
incomingVoiceCallDialogTitle String
The title of the incoming voice call dialog, The default value is inviter's name.
getter/setter pair
incomingVoiceCallPageMessage String
The message of the incoming voice call page, The default value is "Incoming voice call...".
getter/setter pair
incomingVoiceCallPageTitle String
The title of the incoming voice call page, The default value is inviter's name.
getter/setter pair
minimizedCallingPageWaitingText String
The text shown in minimized calling page when waiting for answer, The default value is "Waiting for answer".
getter/setter pair
missedAudioCallNotificationContent String
The content of the audio missed call notification, The default value is Audio Call.
getter/setter pair
missedCallNotificationTitle String
The title of the missed call notification, The default value is Missed Call.
getter/setter pair
missedGroupAudioCallNotificationContent String
The content of the group audio missed call notification, The default value is Group Audio Call.
getter/setter pair
missedGroupVideoCallNotificationContent String
The content of the group video missed call notification, The default value is Group Video Call.
getter/setter pair
missedVideoCallNotificationContent String
The content of the video missed call notification, The default value is Video Call.
getter/setter pair
outgoingCallPageACancelButton String
The button on the call bottom bar to cancel current outgoing call. The default value is "Cancel".
getter/setter pair
outgoingGroupVideoCallPageMessage String
The message of the outgoing group video call page, The default value is "Calling...".
getter/setter pair
outgoingGroupVideoCallPageTitle String
The title of the outgoing group video call page, The default value is first invitee's name.
getter/setter pair
outgoingGroupVoiceCallPageMessage String
The message of the outgoing group voice call page, The default value is "Calling...".
getter/setter pair
outgoingGroupVoiceCallPageTitle String
The title of the outgoing group voice call page, The default value is first invitee's name.
getter/setter pair
outgoingVideoCallPageMessage String
The message of the outgoing video call page, The default value is "Calling..."
getter/setter pair
outgoingVideoCallPageTitle String
The title of the outgoing video call page, The default value is first invitee's name.
getter/setter pair
outgoingVoiceCallPageMessage String
The message of the outgoing voice call page, The default value is "Calling..."
getter/setter pair
outgoingVoiceCallPageTitle String
The title of the outgoing voice call page, The default value is first invitee's name.
getter/setter pair
permissionConfirmDialogAllowButton String
The allow button text of the permission request, The default value is "Allow".
getter/setter pair
permissionConfirmDialogCancelButton String
The deny button text of the permission request, The default value is "Cancel".
getter/setter pair
permissionConfirmDialogDenyButton String
The deny button text of the permission request, The default value is "Deny".
getter/setter pair
permissionConfirmDialogOKButton String
The deny button text of the permission request, The default value is "OK".
getter/setter pair
permissionConfirmDialogTitle String
The allow button text of the permission request, The default value is "Allow $appName to $subTitle".
getter/setter pair
permissionManuallyConfirmDialogSubTitle String
The title of the dialog tips for some permissions cannot be obtained directly and must be set manually by the user The default value is: '• Allow auto launch\n' '• Allow notification on Banner and Lock screen\n' '• Allow display over other apps\n' '• Show on lock screen\n' '• Show floating window\n' '• Pop up interface in background\n'
getter/setter pair
permissionManuallyConfirmDialogTitle String
The title of the dialog tips for some permissions cannot be obtained directly and must be set manually by the user The default value is: Please manually enable the following permissions:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemAlertWindowConfirmDialogSubTitle String
The title of the systemAlertWindow permission request confirmation dialog, The default value is Display over other apps.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncFrom(ZegoCallInvitationInnerText innerText) → void

Available on ZegoCallInvitationInnerText, provided by the ZegoCallInvitationInnerTextForCallInvitationServicePrivate extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited