ZegoCallInvitationUIConfig class

Call invitation UI configuration class for invitation interface styling and custom builders.

Available extensions

Properties

acceptButton ZegoCallButtonUIConfig

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated4110 extension

getter/setter pair
cancelButton ZegoCallButtonUIConfig

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated4110 extension

getter/setter pair
declineButton ZegoCallButtonUIConfig

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated4110 extension

getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
invitee ZegoCallInvitationInviteeUIConfig
getter/setter pair
inviter ZegoCallInvitationInviterUIConfig
getter/setter pair

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated4110 extension

getter/setter pair
prebuiltWithSafeArea bool

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationConfigDeprecated4177 extension

getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCancelInvitationButton bool

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated420 extension

getter/setter pair
showDeclineButton bool

Available on ZegoCallInvitationUIConfig, provided by the ZegoCallInvitationUIConfigDeprecated420 extension

getter/setter pair
withSafeArea bool
does invitation widget display with SafeArea or not
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited